summaryrefslogtreecommitdiffstats
path: root/sbin/fsck_ffs/fsutil.c
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
committertrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
commit136be46680c6e4a18cc827da991d4f9a0de29cba (patch)
treeb5ee0aba66633a4e0e47097e4f383c253a87887a /sbin/fsck_ffs/fsutil.c
parent9618da3e35435c433d8086d65af15f716ffe32ec (diff)
downloadFreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.zip
FreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.tar.gz
s/filesystem/file system/g as discussed on -developers
Diffstat (limited to 'sbin/fsck_ffs/fsutil.c')
-rw-r--r--sbin/fsck_ffs/fsutil.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sbin/fsck_ffs/fsutil.c b/sbin/fsck_ffs/fsutil.c
index 6776656..705426a 100644
--- a/sbin/fsck_ffs/fsutil.c
+++ b/sbin/fsck_ffs/fsutil.c
@@ -530,13 +530,13 @@ catch(int sig __unused)
/*
* When preening, allow a single quit to signal
* a special exit after filesystem checks complete
* so that reboot sequence may be interrupted.
*/
void
catchquit(int sig __unused)
{
- printf("returning to single-user after filesystem check\n");
+ printf("returning to single-user after file system check\n");
returntosingle = 1;
(void)signal(SIGQUIT, SIG_DFL);
}
@@ -585,7 +585,7 @@ dofix(struct inodesc *idesc, const char *msg)
/*
* An unexpected inconsistency occured.
* Die if preening or filesystem is running with soft dependency protocol,
* otherwise just print message and continue.
*/
void
@@ -530,13 +530,13 @@ catch(int sig __unused)
/*
* When preening, allow a single quit to signal
- * a special exit after filesystem checks complete
+ * a special exit after file system checks complete
* so that reboot sequence may be interrupted.
*/
@@ -585,7 +585,7 @@ dofix(struct inodesc *idesc, const char *msg)
/*
* An unexpected inconsistency occured.
- * Die if preening or filesystem is running with soft dependency protocol,
+ * Die if preening or file system is running with soft dependency protocol,
* otherwise just print message and continue.
*/
OpenPOWER on IntegriCloud